==> next-ft-api-client-3.12.0.tgz: package/src/content-legacy.js <==
'use strict';

var capiV1 = require('./utils/capi-v1');
var fetchres = require('fetchres');
var logger = require('ft-next-logger');
var eagerFetch = require('./utils/eager-fetch');
var signedFetch = require('./utils/elastic-fetch');
var elasticAgent = require('./utils/elastic-agent');

module.exports = function(opts) {
	var uuid = opts.uuid;
	var useElasticSearch = opts.useElasticSearch;
	var useElasticSearchOnAws = opts.useElasticSearchOnAws;
	var bodyFormat = opts.bodyFormat || 'structured';
	var returnMany = true;
	if (Array.isArray(uuid)) {
		if (uuid.length === 0) {
			return Promise.resolve([]);
		}
	} else {
		uuid = [uuid];
		returnMany = false;
	}

	if (useElasticSearch && !process.env.ELASTIC_SEARCH_HOST) {
		throw new Error('Cannot use elastic search without an ELASTIC_SEARCH_HOST');
	}

	if (useElasticSearch) {
		return (useElasticSearchOnAws ? signedFetch : eagerFetch)('https://' + process.env.ELASTIC_SEARCH_HOST + '/v1_api_v2/item/_mget', {
				retry: 0,
				method: 'POST',
				body: JSON.stringify({ ids: uuid }),
				timeout: 3000,
				agent: elasticAgent
			})
			.then(function(response) {
				if (!response.ok) {
					logger.warn('Failed getting CAPIv1 content', {
						uuid: uuid,
						status: response.status
					});
				}
				return response;
			})
			.then(fetchres.json)
			.then(function(data) {
				var foundCount = 0;
				var docs = data.docs

					// Filter out any that haven't been found
					.filter(function(item) {
						if (item.found) {
							foundCount++;
							return true;
						}
					})
					.map(function(item) {
						return item._source;
					});
				if (returnMany) {
					return docs;
				}
				if (foundCount === 0) {
					throw new fetchres.BadServerResponseError(404);
				}
				return docs[0];
			});
	}

	return Promise.all(uuid.map(function(uuid) {
		return capiV1({
			uuid: uuid,
			bodyFormat: bodyFormat
		})
			.catch(function(err) {
				if (returnMany) {
					return undefined;
				}
				throw err;
			});
	}))
		.then(function(items) {
			if (returnMany) {
				return items;
			}
			return items[0];
		});
};

==> next-ft-api-client-3.13.0.tgz: package/src/content-legacy.js <==
'use strict';

var capiV1 = require('./utils/capi-v1');
var fetchres = require('fetchres');
var logger = require('ft-next-logger');
var signedFetch = require('signed-aws-es-fetch');
var elasticAgent = require('./utils/elastic-agent');

module.exports = function(opts) {
	var uuid = opts.uuid;
	var useElasticSearch = opts.useElasticSearch;
	var bodyFormat = opts.bodyFormat || 'structured';
	var returnMany = true;
	if (Array.isArray(uuid)) {
		if (uuid.length === 0) {
			return Promise.resolve([]);
		}
	} else {
		uuid = [uuid];
		returnMany = false;
	}

	if (useElasticSearch) {
		return signedFetch('https://next-elastic.ft.com/v1_api_v2/item/_mget', {
				retry: 0,
				method: 'POST',
				body: JSON.stringify({ ids: uuid }),
				timeout: 3000,
				agent: elasticAgent
			})
			.then(function(response) {
				if (!response.ok) {
					logger.warn('Failed getting CAPIv1 content', {
						uuid: uuid,
						status: response.status
					});
				}
				return response;
			})
			.then(fetchres.json)
			.then(function(data) {
				var foundCount = 0;
				var docs = data.docs

					// Filter out any that haven't been found
					.filter(function(item) {
						if (item.found) {
							foundCount++;
							return true;
						}
					})
					.map(function(item) {
						return item._source;
					});
				if (returnMany) {
					return docs;
				}
				if (foundCount === 0) {
					throw new fetchres.BadServerResponseError(404);
				}
				return docs[0];
			});
	}

	return Promise.all(uuid.map(function(uuid) {
		return capiV1({
			uuid: uuid,
			bodyFormat: bodyFormat
		})
			.catch(function(err) {
				if (returnMany) {
					return undefined;
				}
				throw err;
			});
	}))
		.then(function(items) {
			if (returnMany) {
				return items;
			}
			return items[0];
		});
};
